import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';

import languages from './languages';
import themes from './themes';
import usePrism from './hooks/usePrism';
import useExternalContent from './hooks/useExternalContent';
import defaultLoadExternal from './utils/loadExternal';

Codeblock.propTypes = {
    children: PropTypes.node,
    className: PropTypes.string,
    loadExternal: PropTypes.func,
    language: PropTypes.oneOf(Object.keys(languages)),
    theme: PropTypes.oneOf(Object.keys(themes)),
    component: PropTypes.string,
    innerComponent: PropTypes.string,
    src: PropTypes.string
};

export default function Codeblock({
    children,
    className,
    src,
    loadExternal = defaultLoadExternal,
    language = 'javascript',
    theme = 'okaidia',
    component: Outer = 'pre',
    innerComponent: Inner = 'code',
    ...props
}) {
    const ref = React.useRef(null);
    const content = src ? useExternalContent(src, loadExternal) : children;
    usePrism(ref, language, theme);

    return (
        <Outer
            {...props}
            ref={ref}
            className={cx('Codeblock', className, {
                [`language-${language}`]: language
            })}
        >
            <Inner>{content}</Inner>
        </Outer>
    );
}
