import React from 'react';
import loadModule from '../utils/loadModule';

/**
 * Applies prism highlighting to a given element
 * @param {Element} ref the target DOM element
 */
export default function usePrism(ref, language, theme) {
    React.useEffect(() => {
        try {
            applyPrism(ref, language, theme);
        } catch (error) {
            console.warn('[usePrism] failed', { error });
        }
    }, [ref, language, theme]);
}

async function applyPrism(ref, language, theme) {
    const Prism = await import(/* webpackChunkName: 'codeblock/prism' */ 'prismjs');

    await loadModule('theme', theme);
    await loadModule('language', language);

    if (ref && ref.current) {
        Prism.highlightElement(ref.current);
    }
}
